/*
 * This is an unoptimized version of a function that will encrypt and decrypt
 * strings based on the technique described at the GeoCache site. It's really
 * just an example of an API function that does this, so it could be included
 * in some timing tests that I was running (versus native LotusScript).
 *
 * Essentially, this is just a simple letter replacement algorithm, using the
 * following substitution scheme:
 *
 * A B C D E F G H I J K L M
 * N O P Q R S T U V W X Y Z
 *
 * If you really wanted to squeeze some extra speed out of this routine, you
 * could use a lookup table for the replacement characters instead of calculating
 * each one individually, as I do below.
 *
 * Julian Robichaux, http://www.nsftools.com
 *
 */

#include <stdio.h>
#include <string.h>

#if !defined(DLLEXPORT)
#ifdef WIN32
#define DLLEXPORT __declspec(dllexport)
#else
#define DLLEXPORT
#endif
#endif


// use DLLEXPORT to export the function, so we can call it from LotusScript
// (this works even though this is an EXE file instead of a DLL)
DLLEXPORT void GeoCrypt (char *string)
{
	char c;
		
	while (c = *string)
	{
		if (c == '[') {
			while ((*string) && (*string != ']'))
				*string++;
		} else if ((c >= 'a') && (c <= 'z')) {
			*string++ = ((c - 'a' + 13) % 26) + 'a';
		} else if ((c >= 'A') && (c <= 'Z')) {
			*string++ = ((c - 'A' + 13) % 26) + 'A';
		} else {
			*string++;
		}
	}
}


// Here's a simple command line interface to test the functionality
void main (int argc, char *argv[])
{
	char *string;
	
	if (argc < 2)
	{
		printf("USAGE: geocrypt <string>\n\n");
		printf("This will encrypt or decrypt a string using the technique\n");
		printf("described on the GeoCache website.\n\n");
		return ;
	}
	
	string = argv[1];
	printf("original  = %s\n", string);

	GeoCrypt(string);
	printf("encrypted = %s\n", string);
	GeoCrypt(string);
	printf("decrypted = %s\n", string);

}

